import logging
import unittest

import numpy as np

from tasks.src.a_task import swap_gate

logger = logging.getLogger(__name__)
logging.basicConfig(level=logging.INFO)


class ATaskTest(unittest.TestCase):

    def test_a_task(self):
        """
        Test functionalities of swap gate on 2-qubits
        """

        qubit_0 = np.array([1, 0])
        qubit_1 = np.array([0, 1])

        qubit_00 = np.kron(qubit_0, qubit_0)
        qubit_11 = np.kron(qubit_1, qubit_1)
        qubit_01 = np.kron(qubit_0, qubit_1)
        qubit_10 = np.kron(qubit_1, qubit_0)

        # ensure input is a 2-qubit
        self.assertTrue(qubit_00.shape[0] == 4)
        self.assertTrue(qubit_01.shape[0] == 4)
        self.assertTrue(qubit_10.shape[0] == 4)
        self.assertTrue(qubit_11.shape[0] == 4)

        self.assertTrue(np.array_equal(np.dot(swap_gate(), qubit_00), qubit_00))
        self.assertTrue(np.array_equal(np.dot(swap_gate(), qubit_11), qubit_11))

        self.assertTrue(np.array_equal(np.dot(swap_gate(), qubit_01), qubit_10))
        self.assertTrue(np.array_equal(np.dot(swap_gate(), qubit_10), qubit_01))

        logger.info("Logging for fun!")


if __name__ == '__main__':
    unittest.main()
